==> monav_0.2.20101211-1.tar.gz: monav-0.2.20101211/plugins/gpsgrid/gpsgrid.h <==
/*
Copyright 2010  Christian Vetter veaac.fdirct@gmail.com

This file is part of MoNav.

MoNav is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MoNav is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MoNav.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GPSGRID_H
#define GPSGRID_H

#include "interfaces/ipreprocessor.h"
#include "ggdialog.h"
#include "cell.h"
#include "table.h"
#include <vector>


class GPSGrid : public QObject, public IPreprocessor {
	Q_OBJECT
	Q_INTERFACES( IPreprocessor )

public:

	GPSGrid();
	virtual ~GPSGrid();
	virtual QString GetName();
	virtual int GetFileFormatVersion();
	virtual Type GetType();
	virtual QWidget* GetSettings();
	virtual bool LoadSettings( QSettings* settings );
	virtual bool SaveSettings( QSettings* settings );
	virtual bool Preprocess( IImporter* importer, QString dir );

protected:

	struct GridImportEdge {
		unsigned edge;
		int x;
		int y;
		bool operator<( const GridImportEdge& right ) const {
			if ( x != right.x )
				return x < right.x;
			return y < right.y;
		}
	};

	bool clipHelper( double directedProjection, double directedDistance, double* tMinimum, double* tMaximum );
	bool clipEdge( ProjectedCoordinate source, ProjectedCoordinate target, ProjectedCoordinate min, ProjectedCoordinate max );

	GGDialog* m_settingsDialog;
};

#endif // GPSGRID_H

==> monav_0.3.orig.tar.gz: monav-0.3/plugins/gpsgrid/gpsgrid.h <==
/*
Copyright 2010  Christian Vetter veaac.fdirct@gmail.com

This file is part of MoNav.

MoNav is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MoNav is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MoNav.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GPSGRID_H
#define GPSGRID_H

#include "interfaces/ipreprocessor.h"
#include "interfaces/iguisettings.h"
#include "utils/coordinates.h"

class GPSGrid :
		public QObject,
#ifndef NOGUI
		public IGUISettings,
#endif
		public IPreprocessor
{
	Q_OBJECT
	Q_INTERFACES( IPreprocessor )
#ifndef NOGUI
	Q_INTERFACES( IGUISettings )
#endif

public:

	GPSGrid();
	virtual ~GPSGrid();

	// IPreprocessor
	virtual QString GetName();
	virtual int GetFileFormatVersion();
	virtual Type GetType();
	virtual bool LoadSettings( QSettings* settings );
	virtual bool SaveSettings( QSettings* settings );
	virtual bool Preprocess( IImporter* importer, QString dir );

#ifndef NOGUI
	// IGUISettings
	virtual bool GetSettingsWindow( QWidget** window );
	virtual bool FillSettingsWindow( QWidget* window );
	virtual bool ReadSettingsWindow( QWidget* window );
#endif

protected:

	struct GridImportEdge {
		unsigned edge;
		int x;
		int y;
		bool operator<( const GridImportEdge& right ) const {
			if ( x != right.x )
				return x < right.x;
			return y < right.y;
		}
	};

	bool clipHelper( double directedProjection, double directedDistance, double* tMinimum, double* tMaximum );
	bool clipEdge( ProjectedCoordinate source, ProjectedCoordinate target, ProjectedCoordinate min, ProjectedCoordinate max );
};

#endif // GPSGRID_H
